@@ -15,53 +15,55 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-from typing import TYPE_CHECKING, Iterable, Mapping, Optional, Union
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Iterable, Mapping, Sequence
 
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
 from airflow.providers.microsoft.mssql.hooks.mssql import MsSqlHook
-from airflow.utils.decorators import apply_defaults
+from airflow.www import utils as wwwutils
 
 if TYPE_CHECKING:
-    from airflow.hooks.dbapi import DbApiHook
+    from airflow.providers.common.sql.hooks.sql import DbApiHook
+    from airflow.utils.context import Context
 
 
 class MsSqlOperator(BaseOperator):
     """
     Executes sql code in a specific Microsoft SQL database
 
+    .. seealso::
+        For more information on how to use this operator, take a look at the guide:
+        :ref:`howto/operator:MsSqlOperator`
+
     This operator may use one of two hooks, depending on the ``conn_type`` of the connection.
 
     If conn_type is ``'odbc'``, then :py:class:`~airflow.providers.odbc.hooks.odbc.OdbcHook`
     is used.  Otherwise, :py:class:`~airflow.providers.microsoft.mssql.hooks.mssql.MsSqlHook` is used.
 
-    :param sql: the sql code to be executed
-    :type sql: str or string pointing to a template file with .sql
-        extension. (templated)
+    :param sql: the sql code to be executed (templated)
     :param mssql_conn_id: reference to a specific mssql database
-    :type mssql_conn_id: str
     :param parameters: (optional) the parameters to render the SQL query with.
-    :type parameters: dict or iterable
     :param autocommit: if True, each command is automatically committed.
         (default value: False)
-    :type autocommit: bool
     :param database: name of database which overwrite defined one in connection
-    :type database: str
     """
 
-    template_fields = ('sql',)
-    template_ext = ('.sql',)
+    template_fields: Sequence[str] = ('sql',)
+    template_ext: Sequence[str] = ('.sql',)
+    # TODO: Remove renderer check when the provider has an Airflow 2.3+ requirement.
+    template_fields_renderers = {'sql': 'tsql' if 'tsql' in wwwutils.get_attr_renderer() else 'sql'}
     ui_color = '#ededed'
 
-    @apply_defaults
     def __init__(
         self,
         *,
-        sql: str,
+        sql: str | Iterable[str],
         mssql_conn_id: str = 'mssql_default',
-        parameters: Optional[Union[Mapping, Iterable]] = None,
+        parameters: Iterable | Mapping | None = None,
         autocommit: bool = False,
-        database: Optional[str] = None,
+        database: str | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -70,9 +72,9 @@ class MsSqlOperator(BaseOperator):
         self.parameters = parameters
         self.autocommit = autocommit
         self.database = database
-        self._hook: Optional[Union[MsSqlHook, 'DbApiHook']] = None
+        self._hook: MsSqlHook | DbApiHook | None = None
 
-    def get_hook(self) -> Optional[Union[MsSqlHook, 'DbApiHook']]:
+    def get_hook(self) -> MsSqlHook | DbApiHook | None:
         """
         Will retrieve hook as determined by :meth:`~.Connection.get_hook` if one is defined, and
         :class:`~.MsSqlHook` otherwise.
@@ -88,7 +90,7 @@ class MsSqlOperator(BaseOperator):
                 self._hook = MsSqlHook(mssql_conn_id=self.mssql_conn_id, schema=self.database)
         return self._hook
 
-    def execute(self, context: dict) -> None:
+    def execute(self, context: Context) -> None:
         self.log.info('Executing: %s', self.sql)
         hook = self.get_hook()
         hook.run(  # type: ignore[union-attr]
